summaryrefslogtreecommitdiff
path: root/test/player_test.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2020-10-01 10:44:11 +0200
committerCarl Hetherington <cth@carlh.net>2020-10-12 17:33:27 +0200
commit0caa6358a49c66d52d2af090bd2a130203673807 (patch)
tree7c63dede88cf4283d2d58c1f7e0c0c4cafcc91d6 /test/player_test.cc
parent5e4fc69d934546e2170a752bb0bc6d42b0542078 (diff)
Remove Image/GraphicsMagick dependency.
Diffstat (limited to 'test/player_test.cc')
-rw-r--r--test/player_test.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/player_test.cc b/test/player_test.cc
index a68d76083..e52a73e5e 100644
--- a/test/player_test.cc
+++ b/test/player_test.cc
@@ -223,12 +223,12 @@ BOOST_AUTO_TEST_CASE (player_seek_test)
butler->seek (t, true);
pair<shared_ptr<PlayerVideo>, DCPTime> video = butler->get_video(true, 0);
BOOST_CHECK_EQUAL(video.second.get(), t.get());
- write_image(video.first->image(bind(PlayerVideo::force, _1, AV_PIX_FMT_RGB24), false, true), String::compose("build/test/player_seek_test_%1.png", i), "RGB");
- /* This 0.055 is empirically chosen (hopefully) to accept changes in rendering between the reference and a test machine
+ write_image(video.first->image(bind(PlayerVideo::force, _1, AV_PIX_FMT_RGB24), false, true), String::compose("build/test/player_seek_test_%1.png", i));
+ /* This 14.08 is empirically chosen (hopefully) to accept changes in rendering between the reference and a test machine
(17.10 and 16.04 seem to anti-alias a little differently) but to reject gross errors e.g. missing fonts or missing
text altogether.
*/
- check_image(String::compose("test/data/player_seek_test_%1.png", i), String::compose("build/test/player_seek_test_%1.png", i), 0.055);
+ check_image(String::compose("test/data/player_seek_test_%1.png", i), String::compose("build/test/player_seek_test_%1.png", i), 14.08);
}
}
@@ -256,8 +256,8 @@ BOOST_AUTO_TEST_CASE (player_seek_test2)
butler->seek (t, true);
pair<shared_ptr<PlayerVideo>, DCPTime> video = butler->get_video(true, 0);
BOOST_CHECK_EQUAL(video.second.get(), t.get());
- write_image(video.first->image(bind(PlayerVideo::force, _1, AV_PIX_FMT_RGB24), false, true), String::compose("build/test/player_seek_test2_%1.png", i), "RGB");
- check_image(String::compose("test/data/player_seek_test2_%1.png", i), String::compose("build/test/player_seek_test2_%1.png", i), 0.055);
+ write_image(video.first->image(bind(PlayerVideo::force, _1, AV_PIX_FMT_RGB24), false, true), String::compose("build/test/player_seek_test2_%1.png", i));
+ check_image(String::compose("test/data/player_seek_test2_%1.png", i), String::compose("build/test/player_seek_test2_%1.png", i), 14.08);
}
}